//fichier mesures.c

/****************************************************************
 * Code source de la librairie qui permet de mesurer			*
 *	et de dterminer la couleur de la balle						*
 * .Date de cration : 11/01/08									*
 *  Date de modification : 21/02/08                         	*
 * .Auteurs :  Philipe Lucidarme	 Alexis Barre    			*
 *			   Quentin Dion	           							*
 *                          									*
 *                                                       		*
 * .Descriptions :                                      		*
 *      - 	mesure la valeur des capteurs		  				*
 *        	dtermine la couleur de la balle en fonction        *
 *        	0 = balle blanche 									*
 *		    1 = balle rouge                                     *
 *          2 = balle bleu                                    	*
 * .Remarques :                                         		*
 *																*
 ****************************************************************/
#include <p18f252.h>	// Pour les registres du PIC18F252
#include <usart.h>		// Pour le priphrique USART qui gre la liaison srie
#include <delays.h>    	// Pour les temporisations
#include <adc.h>
#include <stdio.h>		// pour utiliser le printf 

#include "led.h"
#include "CAN.h"
#include "mesures.h"


/////////////////////////////////////////////////////////////////////////////
//                                                                         //
//                            Fonction Mesures	                          //
//                                                                         //
/////////////////////////////////////////////////////////////////////////////
// --------------------------------------------------------------------------
/* Mesures sur le capteurs
 *  0 = balle blanche
 *  1 = balle rouge
 *  2 = balle bleue
 *	3 = pas de balle
*/
unsigned char Mesures(void)
{
		int bleu[3],blanc[3],rouge[3],vide[3];
        int SumBleu,SumBlanc,SumRouge;
		//Mesure " vide"

		Leds_Bleus(0);									//extinction des LEDS
		Leds_Blanches(0);
		Leds_Rouges(0);
		vide[0]=CAN_Convert(ADC_CH0); 					//valeur capteur1 avec LEDS Eteintes	
		vide[1]=CAN_Convert(ADC_CH1);					//valeur capteur2 avec LEDS Eteintes
		vide[2]=CAN_Convert(ADC_CH2);					//valeur capteur3 avec LEDS Eteintes
		printf ("vide : %d-%d-%d \t ",vide[0],vide[1],vide[2]);

		// Mesures avec leds Bleues
		Leds_Bleus(1);									//allumer leds bleues
		Delay100TCYx(5);	
		bleu[0]=CAN_Convert(ADC_CH0)-vide[0];			//val du capteur bleu 1 - Valeur  vide du capteur 1
		bleu[1]=CAN_Convert(ADC_CH1)-vide[1];			//val du capteur bleu 2 - Valeur  vide du capteur 2
		bleu[2]=CAN_Convert(ADC_CH2)-vide[2];			//val du capteur bleu 3 - Valeur  vide du capteur 3
		Leds_Bleus(0);
		printf ("bleu : %d-%d-%d \t ",bleu[0],bleu[1],bleu[2]);	
	
		// Mesures avec Leds Blanches
		Leds_Blanches(1);
		Delay100TCYx(5);
		blanc[0]=CAN_Convert(ADC_CH0)-vide[0];			//val du capteur blanc 1 - Valeur  vide du capteur 1
		blanc[1]=CAN_Convert(ADC_CH1)-vide[1];		
		blanc[2]=CAN_Convert(ADC_CH2)-vide[2];
		Leds_Blanches(0);
		printf ("blanc : %d-%d-%d \t ",blanc[0],blanc[1],blanc[2]);	
	
		// Mesures avec Leds Rouges
		Leds_Rouges(1);
		Delay100TCYx(5);
		rouge[0]=CAN_Convert(ADC_CH0)-vide[0];			//val du capteur rouge 1 - Valeur  vide du capteur 1
		rouge[1]=CAN_Convert(ADC_CH1)-vide[1];
		rouge[2]=CAN_Convert(ADC_CH2)-vide[2];
		Leds_Rouges(0);
		printf ("rouge : %d-%d-%d \n ",rouge[0],rouge[1],rouge[2]); 

		// additions des mesures de chaques capteurs 
		SumRouge=rouge[0]+rouge[1]+rouge[2];
		SumBlanc=blanc[0]+blanc[1]+blanc[2];
		SumBleu =bleu[0] +bleu[1] +bleu [2];
		

		return(Calculs (SumBleu,SumBlanc,SumRouge));



        
}

/////////////////////////////////////////////////////////////////////////////
//                                                                         //
//                            Fonction Calculs	                           //
//                                                                         // 
/////////////////////////////////////////////////////////////////////////////

unsigned char Calculs (int SumBleu,int SumBlanc,int SumRouge)
{
	
	unsigned char balle=5;								//initialise balle  une valeur diffrentes
	if (SumBleu+SumBlanc+SumRouge>450)					// Si il y a une balle
		{
			if (SumBlanc>1000)							// seuil de la balle blanche
			{
					
					Leds_Blanches(1);
					Delay10KTCYx(10);
					Leds_Blanches(0);
					balle=0;
		
			}
			else
			{
				if ((SumRouge>300)&&(SumBleu<100))		// seuil de la balle rouge
				{
					Leds_Rouges(1);
					Delay10KTCYx(10);
					Leds_Rouges(0);		
					balle=1;						
					
				}
				
 				else								
				{
														// sinon balle bleue			
					Leds_Bleus(1);
					Delay10KTCYx(10);
					Leds_Bleus(0);
					balle=2;					
				}
			}
		}
	else balle=4;
        return(balle);
}